// See the Electron documentation for details on how to use preload scripts:
// https://www.electronjs.org/docs/latest/tutorial/process-model#preload-scripts

import { contextBridge, ipcRenderer } from 'electron';
import { ApiResponse, MenuItem, TagResolutionConfig } from './EIAC_Desktop_Api';

contextBridge.exposeInMainWorld('electronAPI', {
  /**
   * 获取缓存
   * @param key 键
   * @returns 缓存
   */
  getCacheAsync: (key: string) => ipcRenderer.invoke('cache:get', key) as Promise<any>,
  /**
   * 设置缓存
   * @param key 键
   * @param value 值
   */
  setCacheAsync: (key: string, value: any) => ipcRenderer.invoke('cache:set', key, value) as Promise<void>,
  /**
   * 获取菜单缓存
   * @returns 菜单缓存
   */
  getMenuCacheAsync: () => ipcRenderer.invoke('get-menu-cache') as Promise<ApiResponse<MenuItem[]>>,

  /**
   * 获取帮助描述
   * @param code 帮助描述代码
   * @returns 帮助描述
   */
  getHelperDescripAsync: (code: string) => ipcRenderer.invoke('get-helper-descrip', code) as Promise<string | null>,

  /**
   * 获取指定URL的缩放比例
   * @param url 要获取缩放比例的URL
   * @returns 缩放比例
   */
  getZoomFactorByUrl: (url: string) => ipcRenderer.invoke('get-zoom-factor-by-url', url) as Promise<number>,

  /**
   * 在新标签页打开URL
   * @param callback 回调函数，参数为webContentId和url。其中webContentId是请求打开URL的webview的id。
   */
  onOpenTab: (callback: (webContentId: number, url: string) => void) => {
    ipcRenderer.on('webview-new-window', (_event, webContentId, url) => callback(webContentId, url));
  },

  /**
   * 检查URL是否可用
   * @param url 要检查的URL
   * @returns 是否可用
   */
  checkUrlAvailable: (url: string) => ipcRenderer.invoke('check-url-available', url) as Promise<boolean>,

  /**
   * 设置webview的cookie
   * @param url 要设置cookie的URL
   * @param cookie cookie字符串
   */
  setWebviewCookie: (url: string, cookie: string) => ipcRenderer.invoke('set-webview-cookie', url, cookie) as Promise<boolean>,

  /**
   * 故障上报
   * @param url 要上报的URL
   * @param message 要上报的消息
   * @param status 要上报的状态
   */
  faultReporting: (url: string, message: string, status: number) => ipcRenderer.invoke('fault-reporting', url, message, status) as Promise<{ ok: boolean; status: number; message?: string }>,

  /**
   * 按键将值设置到sessionStorage
   * @param key 键
   * @param value 值
   */
  setSessionStorage: (key: string, value: string) => {
    window.sessionStorage.setItem(key, value);
  },

  /**
   * 从sessionStorage中获取指定键的值
   * @param key 键
   * @returns 值
   */
  getSessionStorage: (key: string) => {
    return window.sessionStorage.getItem(key);
  },

  /**
   * 从sessionStorage中删除指定键的值
   * @param key 键
   */
  removeSessionStorage: (key: string) => {
    window.sessionStorage.removeItem(key);
  },

  /**
   * 清空sessionStorage
   */
  clearSessionStorage: () => {
    window.sessionStorage.clear();
  }
});